@@ -32,11 +32,13 @@ pub struct FilePatcher {
 }
 
 impl FilePatcher {
+    /// Try and build a `FilePatcher` for the given path and query
+    /// Return Ok(None) if there is nothing to replace in the file
     pub fn new(console: &Console, path: &Path, query: &Query) -> Result<Option<FilePatcher>> {
         let mut num_replacements = 0;
         let mut num_lines = 0;
         let file =
-            File::open(&path).with_context(|| format!("Could not open {}", path.display()))?;
+            File::open(path).with_context(|| format!("Could not open {}", path.display()))?;
         let reader = BufReader::new(file);
         let mut new_contents = String::new();
         // Note: not using lines() because we need to preserve the line endings
@@ -62,12 +64,16 @@ impl FilePatcher {
                 }
             }
         }
-        Ok(Some(FilePatcher {
-            path: path.to_path_buf(),
-            new_contents,
-            num_lines,
-            num_replacements,
-        }))
+        if num_replacements == 0 {
+            Ok(None)
+        } else {
+            Ok(Some(FilePatcher {
+                path: path.to_path_buf(),
+                new_contents,
+                num_lines,
+                num_replacements,
+            }))
+        }
     }
 
     pub(crate) fn num_replacements(&self) -> usize {
